@@ -11,7 +11,7 @@ class Parameters:
     env = None
 
     # CONFIGURACION PARA UTILIZAR CSV DESDE SHAREPOINT
-    #sharepoint_data_jmeter=None
+    # sharepoint_data_jmeter=None
 
     # CONFIGURACION FORMATO DE FECHA
     date_format = '%d/%m/%Y'
@@ -31,21 +31,14 @@ class Parameters:
     environment = platform.system()
     enviroment_confguration = os.getenv('PYBOT_SYSTEM')
     environment_record = os.getenv('PYBOT_RECORD')
-    environment_browser = os.getenv('PYBOT_BROWSER')
-
-    # CONFIGURACION DE BROWSER Y PRUEBAS
-    if environment_browser is None:
-        browser = 'EDGE'
-    if environment_browser == 'EDGE':
-        browser = 'EDGE'
-    if environment_browser == 'CHROME':
-        browser = 'CHROME'
 
+    # CONFIOGURACION DE BROWSER Y PRUEBASto
+    browser = 'EDGE' if enviroment_confguration is None else 'CHROME'
     debug = False
     headless = False
 
-    record = False if environment_record is None else False if environment_record.lower() == "false" else bool(environment_record)
-    #VARIABLE LISTA DE PASOS
+    record = False if environment_record is None else True
+    # VARIABLE LISTA DE PASOS
     steps_list = []
 
     # CONFIGURACION INCREMENTO AUTO/MANUALEXCEL
@@ -85,4 +78,4 @@ class Parameters:
 
     # CONFIGURACION PARA NOTIFICACIONES DE TEAMS
     teams_notifications_colors = "#5b5fc7"
-    teams_focus_test_colors = "#383966"
\ No newline at end of file
+    teams_focus_test_colors = "#383966"
